# coding: utf-8

require 'fileutils'

require 'spec_helper'

require 'chef/knife/hitori_config'


describe 'hitori_config' do
  before do
    Chef::Knife::HitoriConfig.load_deps
    @obj = Chef::Knife::HitoriConfig.new
    @obj.ui.stub(:info, :msg)
    setup_interactive_response
  end

  def setup_interactive_response
    @obj.stub(:input_arg) { |message, args|
      case message
        when /availability_zone/ then
          'MY_AZ'
        when /aws_access_key_id/ then
          'MY_access_key'
        when /aws_secret_access_key/ then
          'MY_secret'
        when /ami image/ then
          'MY_ami'
        when /flavor/ then
          'MY_flavor'
        when /Security Group/ then
          'MY_group'
        when /ssh_user/ then
          'MY_user'
        when /identity_file/ then
          'MY_identity.pem'
        when /ssh_key_name/ then
          'MY_ssh_key_name'
        when /region/ then
          'MY_region'
        when /overwrite knife/ then
          (@obj.config[:yes] || 'Y')
      end
    }
  end

  describe :run do
    def knife_ruby_path
      "#{@temp_dir}/.chef/knife.rb"
    end

    def knife_ec2_ruby_path
      "#{@temp_dir}/.chef/ec2.rb"
    end

    before do
      @temp_dir = Dir.mktmpdir
      @obj.config[:base_dir] = @temp_dir
    end

    after do
      FileUtils.remove_entry_secure(@temp_dir)
    end

    context 'brand new' do
      it 'should not call input_arg for overwrite knife.rb' do
        @obj.should_not_receive(:input_arg).with(/overwrite knife.rb/, 'N')
        @obj.run
      end

      it 'should create knife.rb' do
        @obj.run
        ::File.exists?(knife_ruby_path).should be_true
      end

      it 'should create ec2.rb' do
        @obj.run
        ::File.exists?(knife_ec2_ruby_path).should be_true
      end
    end

    context 'knife.rb exists already' do
      before do
        @content = 'knife[:fruit] = "apple"'
        FileUtils.makedirs(::File.dirname(knife_ruby_path))
        ::File.write(knife_ruby_path, @content)
      end

      it 'should call input_arg for overwrite knife.rb' do
        @obj.should_receive(:input_arg).with(/overwrite knife.rb/, 'N')
        @obj.run
      end

      it 'should overwrite if user input y' do
        @obj.config[:yes] = 'y'
        @obj.run
        ::File.read(knife_ruby_path).should_not == @content
      end

      it 'should not overwrite if user input n' do
        @obj.config[:yes] = 'n'
        @obj.run
        ::File.read(knife_ruby_path).should == @content
      end
    end
  end
end
