require 'spec_helper'

require 'chef/knife/hitori_data_bag_enc'

describe 'HitoriDataBagEnc' do
  before do
    Chef::Knife::HitoriDataBagEnc.load_deps
    @obj = Chef::Knife::HitoriDataBagEnc.new
    @obj.name_args = %w(MY_BAG MY_ITEM)
    @obj.config[:json_file] = 'my.json'
    Chef::Config[:encrypted_data_bag_secret] = '/tmp/enc.key'
  end

  describe :run do
    it 'should call update_environment if config[:environment]' do
      @obj.config[:environment] = 'apple'
      @obj.should_receive(:update_environment).with('apple')
      common_run
    end

    it 'should not call update_environment if not config[:environment]' do
      @obj.config[:environment] = nil
      @obj.should_not_receive(:update_environment)
      common_run
    end

    def common_run
      @obj.should_receive(:create_data_bag)
      @obj.run
    end
  end

  describe :create_data_bag do
    it 'should write encrypted data to specific path' do
      @obj.config[:bag], @obj.config[:item] = @obj.name_args
      Chef::Config[:data_bag_path] = '/tmp/data_bag'
      Chef::EncryptedDataBagItem.should_receive(:load_secret) {'sec'}
      File.should_receive(:read).with(@obj.config[:json_file]) {'{"a": 9}'}
      @obj.should_receive(:check_data).and_return(true)
      Chef::EncryptedDataBagItem.should_receive(:encrypt_data_bag_item) {
        enc_data = double('enc_data')
        enc_data.should_receive(:to_json) {'enc_to_json'}
        enc_data
      }
      File.should_receive(:write).with('/tmp/data_bag/MY_BAG/MY_ITEM.json', 'enc_to_json')
      @obj.create_data_bag
    end

  end
end
